================
eRepublik script
================


.. image:: https://img.shields.io/pypi/v/erepublik.svg
        :target: https://pypi.python.org/pypi/erepublik

.. image:: https://readthedocs.org/projects/erepublik/badge/?version=latest
        :target: https://erepublik.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://api.codacy.com/project/badge/Grade/eaa7ae43d23f4c0abab65c3bde89475a
        :target: https://app.codacy.com/manual/eeriks/erepublik?utm_source=github.com&utm_medium=referral&utm_content=eeriks/erepublik&utm_campaign=Badge_Grade_Dashboard
        :alt: Codacy Badge


Python package for automated eRepublik playing


* Free software: MIT license
* Documentation: https://erepublik.readthedocs.io/en/latest/


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
